==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/history/translations/history_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/history/translations/history_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>History in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>yesterday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>last week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>last month</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All chats - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Smses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>By date</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buddy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
